==> openflowplugin-extension-nicira-0.8.1-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/flow/mod/spec/flow/mod/spec/FlowModOutputToPortCase.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec;
import org.eclipse.jdt.annotation.Nullable;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.FlowModSpec;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec.flow.mod.output.to.port._case.FlowModOutputToPort;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.DataObject;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * case flow-mod-output-to-port-case {
 *   container flow-mod-output-to-port {
 *     leaf flow-mod-num-bits {
 *       type uint16;
 *     }
 *     leaf src-field {
 *       type uint32;
 *     }
 *     leaf src-ofs {
 *       type uint16;
 *     }
 *   }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/flow-mod-spec/flow-mod-spec/flow-mod-output-to-port-case</i>
 *
 */
public interface FlowModOutputToPortCase
    extends
    DataObject,
    Augmentable<FlowModOutputToPortCase>,
    FlowModSpec
{



    public static final QName QNAME = $YangModuleInfoImpl.qnameOf("flow-mod-output-to-port-case");

    /**
     * @return <code>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec.flow.mod.output.to.port._case.FlowModOutputToPort</code> <code>flowModOutputToPort</code>, or <code>null</code> if not present
     */
    @Nullable FlowModOutputToPort getFlowModOutputToPort();

}

==> openflowplugin-extension-nicira-0.8.2-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/flow/mod/spec/flow/mod/spec/FlowModOutputToPortCase.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec;
import org.eclipse.jdt.annotation.NonNull;
import org.eclipse.jdt.annotation.Nullable;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.FlowModSpec;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec.flow.mod.output.to.port._case.FlowModOutputToPort;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.DataObject;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * case flow-mod-output-to-port-case {
 *   container flow-mod-output-to-port {
 *     leaf flow-mod-num-bits {
 *       type uint16;
 *     }
 *     leaf src-field {
 *       type uint32;
 *     }
 *     leaf src-ofs {
 *       type uint16;
 *     }
 *   }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/flow-mod-spec/flow-mod-spec/flow-mod-output-to-port-case</i>
 *
 */
public interface FlowModOutputToPortCase
    extends
    DataObject,
    Augmentable<FlowModOutputToPortCase>,
    FlowModSpec
{



    public static final @NonNull QName QNAME = $YangModuleInfoImpl.qnameOf("flow-mod-output-to-port-case");

    /**
     * @return <code>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec.flow.mod.output.to.port._case.FlowModOutputToPort</code> <code>flowModOutputToPort</code>, or <code>null</code> if not present
     */
    @Nullable FlowModOutputToPort getFlowModOutputToPort();

}
